// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

//------------------------------------------------------------------------------

#include <xplcommon/Thread.h>
#include <xplcommon/Waiter.h>
#include <xplcommon/LocalServerSocket.h>
#include <xplcommon/LocalAcceptor.h>
#include <xplcommon/LocalSocket.h>
#include <xplcommon/LocalClientSocket.h>
#include <xplcommon/LocalConnector.h>
#include <xplcommon/DataStream.h>
#include <xplcommon/WaitableEvent.h>
#include <xplcommon/PseudoRandom.h>

#include <cstdlib>
#include <cstdio>
#include <cassert>

#include <signal.h>

#include <sys/time.h>

//------------------------------------------------------------------------------

using xplcommon::Thread;
using xplcommon::Waiter;
using xplcommon::LocalServerSocket;
using xplcommon::LocalAcceptor;
using xplcommon::LocalSocket;
using xplcommon::LocalClientSocket;
using xplcommon::LocalConnector;
using xplcommon::BufferedStream;
using xplcommon::DataStream;
using xplcommon::PseudoRandom;

using std::min;

//------------------------------------------------------------------------------

class TestThread : public Thread
{
private:
    unsigned long id;

public:
    TestThread(unsigned long id);

    virtual void run();
};

//------------------------------------------------------------------------------

inline TestThread::TestThread(unsigned long id) :
    Thread(true),
    id(id)
{
}

//------------------------------------------------------------------------------

void TestThread::run()
{
    printf("TestThread: id=%lu\n", id);
}

//------------------------------------------------------------------------------
//------------------------------------------------------------------------------

int main()
{
    static const size_t numThreads = 1000;

    TestThread** threads = new TestThread*[numThreads];

    unsigned long id = 1;
    while(true) {
        for(size_t i = 0; i<numThreads; ++i) {
            threads[i] = new TestThread(id++);
            threads[i]->start();
        }

        Thread::sleep(2000);

        // for(size_t i = 0; i<numThreads; ++i) {
        //     delete threads[i];
        // }
    }

    return 0;
}

//------------------------------------------------------------------------------

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
